@@ -251,7 +251,15 @@ get_config(int *nrows)
 	i++;
 
 	StrNCpy(status[i].name, "pcp_socket_dir", POOLCONFIG_MAXNAMELEN);
-	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->pcp_socket_dir);
+	*(status[i].value) = '\0';
+	for (j = 0; j < pool_config->num_pcp_socket_directories; j++)
+	{
+		len = POOLCONFIG_MAXVALLEN - strlen(status[i].value);
+		strncat(status[i].value, pool_config->pcp_socket_dir[j], len);
+		len = POOLCONFIG_MAXVALLEN - strlen(status[i].value);
+		if (j != pool_config->num_pcp_socket_directories - 1)
+			strncat(status[i].value, ",", len);
+	}
 	StrNCpy(status[i].desc, "PCP socket directory", POOLCONFIG_MAXDESCLEN);
 	i++;
 
@@ -441,6 +449,11 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "if true, print closing connections to the log", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "log_pcp_processes", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->log_pcp_processes);
+	StrNCpy(status[i].desc, "if true, print PCP process forks and a normal exit status to the log", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	StrNCpy(status[i].name, "log_hostname", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->log_hostname);
 	StrNCpy(status[i].desc, "if true, resolve hostname for ps and log print", POOLCONFIG_MAXDESCLEN);
@@ -456,6 +469,11 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "if non 0, logs all SQL statements on each node", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "notice_per_node_statement", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->notice_per_node_statement);
+	StrNCpy(status[i].desc, "if non 0, logs all SQL statements on each node as notice message", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	StrNCpy(status[i].name, "log_client_messages", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->log_client_messages);
 	StrNCpy(status[i].desc, "if non 0, logs any client messages", POOLCONFIG_MAXDESCLEN);
@@ -645,6 +663,11 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "follow primary command", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "user_redirect_preference_list", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->user_redirect_preference_list);
+	StrNCpy(status[i].desc, "redirect by user name", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	StrNCpy(status[i].name, "database_redirect_preference_list", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->database_redirect_preference_list);
 	StrNCpy(status[i].desc, "redirect by database name", POOLCONFIG_MAXDESCLEN);
@@ -1084,8 +1107,6 @@ get_config(int *nrows)
 
 	StrNCpy(status[i].name, "memqcache_stats_start_time", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", ctime(&pool_get_memqcache_stats()->start_time));
-	/* remove a newline added by ctime() */
-	*(strchrnul(status[i].value, '\n')) = '\0';
 	StrNCpy(status[i].desc, "Start time of query cache stats", POOLCONFIG_MAXDESCLEN);
 	i++;
 
@@ -1531,6 +1552,7 @@ get_pools(int *nrows)
 		for (pool = 0; pool < pool_config->max_pool; pool++)
 		{
 			int idle_duration = pi->connection_info[pool * MAX_NUM_BACKENDS].client_idle_duration;
+			int load_balancing_node_id = pi->connection_info[pool * MAX_NUM_BACKENDS].load_balancing_node;
 			int client_idle_time = pool_config->client_idle_limit;
 
 			if (pool_config->client_idle_limit > 0)
@@ -1654,6 +1676,10 @@ get_pools(int *nrows)
 						*(pools[lines].status) = '\0';
 				}
 
+				if (pi->connection_info[poolBE].connected && backend_id == load_balancing_node_id)
+					StrNCpy(pools[lines].load_balance_node, "1", POOLCONFIG_MAXPROCESSSTATUSLEN);
+				else
+					StrNCpy(pools[lines].load_balance_node, "0", POOLCONFIG_MAXPROCESSSTATUSLEN);
 				lines++;
 			}
 		}
@@ -1673,7 +1699,8 @@ pools_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 	static char *field_names[] = {"pool_pid", "start_time", "client_connection_count", "pool_id",
 								  "backend_id", "database", "username", "backend_connection_time",
 								  "client_connection_time", "client_disconnection_time", "client_idle_duration",
-								  "majorversion", "minorversion", "pool_counter", "pool_backendpid", "pool_connected", "status"};
+								  "majorversion", "minorversion", "pool_counter", "pool_backendpid", "pool_connected",
+								  "status", "load_balance_node"};
 	int		n;
 	int		*offsettbl;
 	int		nrows;
